%% 
%% This is file `applemac.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% inputenc.dtx  (with options: `applemac')
%% 
%% 
%% This is a generated file. 
%% 
%% Copyright 1993 1994 1995 1996 
%% The LaTeX3 Project and any individual authors listed elsewhere 
%% in this file. 
%% 
%% For further copyright information, and conditions for modification 
%% and distribution, see the file legal.txt, and any other copyright 
%% notices in this file. 
%% 
%% This file is part of the LaTeX2e system. 
%% ---------------------------------------- 
%% This system is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
%% For error reports concerning UNCHANGED versions of this file no 
%% more than one year old, see bugs.txt. 
%% 
%% Please do not request updates from us directly. Primary 
%% distribution is through the CTAN archives. 
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE: 
%% 
%% You are NOT ALLOWED to distribute this file alone. 
%% 
%% You are allowed to distribute this file under the condition that it 
%% is distributed together with all the files listed in manifest.txt. 
%% 
%% If you receive only some of these files from someone, complain! 
%% 
%% 
%% Permission is granted to copy this file to another file with a 
%% clearly different name and to customize the declarations in that 
%% copy to serve the needs of your installation, provided that you 
%% comply with the conditions in the file legal.txt. 
%% 
%% However, NO PERMISSION is granted to generate or to distribute a 
%% modified version of this file under its original name. 
%% 
%% You are NOT ALLOWED to change this file. 
%% 
%% 
%% MODIFICATION ADVICE: 
%% 
%% If you want to customize this file, it is best to make a copy of 
%% the source file(s) from which it was produced. Use a different 
%% name for your copy(ies) and modify the copy(ies); this will ensure 
%% that your modifications do not get overwritten when you install a 
%% new release of the standard system. You should also ensure that 
%% your modified source file does not generate any modified file with 
%% the same name as a standard file. 
%% 
%% You can then easily distribute your modifications by distributing 
%% the modified and renamed copy of the source file, taking care to 
%% observe the conditions in legal.txt; this will ensure that other 
%% users can safely use your modifications. 
%% 
%% You will also need to produce your own, suitably named, .ins file to 
%% control the generation of files from your source file; this file 
%% should contain your own preambles for the files it generates, not 
%% those in the standard .ins files. 
%% 
%% The names of the source files used are shown above. 
%% 
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
  \ProvidesFile{applemac.def}
   [1996/05/10 v0.9r Input encoding file
                        (test version: liable to change)]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\providecommand{\mathdegree}{{^\circ}}
\providecommand{\mathordmasculine}{{^o}}
\providecommand{\mathordfeminine}{{^a}}
\DeclareInputText{"080}{\"A}
\DeclareInputText{"081}{\AA}
\DeclareInputText{"082}{\c C}
\DeclareInputText{"083}{\@tabacckludge'E}
\DeclareInputText{"084}{\~N}
\DeclareInputText{"085}{\"O}
\DeclareInputText{"086}{\"U}
\DeclareInputText{"087}{\@tabacckludge'a}
\DeclareInputText{"088}{\@tabacckludge`a}
\DeclareInputText{"089}{\^a}
\DeclareInputText{"08A}{\"a}
\DeclareInputText{"08B}{\~a}
\DeclareInputText{"08C}{\aa}
\DeclareInputText{"08D}{\c c}
\DeclareInputText{"08E}{\@tabacckludge'e}
\DeclareInputText{"08F}{\@tabacckludge`e}
\DeclareInputText{"090}{\^e}
\DeclareInputText{"091}{\"e}
\DeclareInputText{"092}{\@tabacckludge'\i}
\DeclareInputText{"093}{\@tabacckludge`\i}
\DeclareInputText{"094}{\^\i}
\DeclareInputText{"095}{\"\i}
\DeclareInputText{"096}{\~n}
\DeclareInputText{"097}{\@tabacckludge'o}
\DeclareInputText{"098}{\@tabacckludge`o}
\DeclareInputText{"099}{\^o}
\DeclareInputText{"09A}{\"o}
\DeclareInputText{"09B}{\~o}
\DeclareInputText{"09C}{\@tabacckludge'u}
\DeclareInputText{"09D}{\@tabacckludge`u}
\DeclareInputText{"09E}{\^u}
\DeclareInputText{"09F}{\"u}
\DeclareInputText{"0A0}{\dag}
\DeclareInputMath{"0A1}{\mathdegree}
\DeclareInputText{"0A2}{\textcent}
\DeclareInputText{"0A3}{\pounds}
\DeclareInputText{"0A4}{\S}
\DeclareInputText{"0A5}{\textbullet}
\DeclareInputText{"0A6}{\P}
\DeclareInputText{"0A7}{\ss}
\DeclareInputText{"0A8}{\textregistered}
\DeclareInputText{"0A9}{\copyright}
\DeclareInputText{"0AA}{\texttrademark}
\DeclareInputText{"0AB}{\@tabacckludge'{}}
\DeclareInputText{"0AC}{\"{}}
\DeclareInputMath{"0AD}{\neq}
\DeclareInputText{"0AE}{\AE}
\DeclareInputText{"0AF}{\O}
\DeclareInputMath{"0B0}{\infty}
\DeclareInputMath{"0B1}{\pm}
\DeclareInputMath{"0B2}{\leq}
\DeclareInputMath{"0B3}{\geq}
\DeclareInputText{"0B4}{\textyen}
\DeclareInputMath{"0B5}{\mu}
\DeclareInputMath{"0B6}{\partial}
\DeclareInputMath{"0B7}{\Sigma}
\DeclareInputMath{"0B8}{\Pi}
\DeclareInputMath{"0B9}{\pi}
\DeclareInputMath{"0BA}{\int}
\DeclareInputMath{"0BB}{\mathordfeminine}
\DeclareInputMath{"0BC}{\mathordmasculine}
\DeclareInputMath{"0BD}{\Omega}
\DeclareInputText{"0BE}{\ae}
\DeclareInputText{"0BF}{\o}
\DeclareInputText{"0C0}{\textquestiondown}
\DeclareInputText{"0C1}{\textexclamdown}
\DeclareInputMath{"0C2}{\lnot}
\DeclareInputMath{"0C3}{\surd}
\DeclareInputText{"0C4}{\textflorin}
\DeclareInputMath{"0C5}{\approx}
\DeclareInputMath{"0C6}{\Delta}
\DeclareInputText{"0C7}{\guillemotleft}
\DeclareInputText{"0C8}{\guillemotright}
\DeclareInputText{"0C9}{\dots}
\DeclareInputText{"0CA}{\nobreakspace}
\DeclareInputText{"0CB}{\@tabacckludge`A}
\DeclareInputText{"0CC}{\~A}
\DeclareInputText{"0CD}{\~O}
\DeclareInputText{"0CE}{\OE}
\DeclareInputText{"0CF}{\oe}
\DeclareInputText{"0D0}{\textendash}
\DeclareInputText{"0D1}{\textemdash}
\DeclareInputText{"0D2}{\textquotedblleft}
\DeclareInputText{"0D3}{\textquotedblright}
\DeclareInputText{"0D4}{\textquoteleft}
\DeclareInputText{"0D5}{\textquoteright}
\DeclareInputMath{"0D6}{\div}
\DeclareInputMath{"0D7}{\diamond}
\DeclareInputText{"0D8}{\"y}
\DeclareInputText{"0D9}{\"Y}
\DeclareInputMath{"0DA}{/}
\DeclareInputText{"0DB}{\textcurrency}
\DeclareInputText{"0DC}{\guilsinglleft}
\DeclareInputText{"0DD}{\guilsinglright}
\DeclareInputText{"0DE}{fi}
\DeclareInputText{"0DF}{fl}
\DeclareInputText{"0E0}{\ddag}
\DeclareInputText{"0E1}{\textperiodcentered}
\DeclareInputText{"0E2}{\quotesinglbase}
\DeclareInputText{"0E3}{\quotedblbase}
\DeclareInputText{"0E4}{\perthousand}
\DeclareInputText{"0E5}{\^A}
\DeclareInputText{"0E6}{\^E}
\DeclareInputText{"0E7}{\@tabacckludge'A}
\DeclareInputText{"0E8}{\"E}
\DeclareInputText{"0E9}{\@tabacckludge`E}
\DeclareInputText{"0EA}{\@tabacckludge'I}
\DeclareInputText{"0EB}{\^I}
\DeclareInputText{"0EC}{\"I}
\DeclareInputText{"0ED}{\@tabacckludge`I}
\DeclareInputText{"0EE}{\@tabacckludge'O}
\DeclareInputText{"0EF}{\^O}
\DeclareInputText{"0F0}{\textapplelogo}
\DeclareInputText{"0F1}{\@tabacckludge`O}
\DeclareInputText{"0F2}{\@tabacckludge'U}
\DeclareInputText{"0F3}{\^U}
\DeclareInputText{"0F4}{\@tabacckludge`U}
\DeclareInputText{"0F5}{\i}
\DeclareInputText{"0F6}{\^{}}
\DeclareInputText{"0F7}{\~{}}
\DeclareInputText{"0F8}{\@tabacckludge={}}
\DeclareInputText{"0F9}{\u{}}
\DeclareInputText{"0FA}{\.{}}
\DeclareInputText{"0FB}{\r{}}
\DeclareInputText{"0FC}{\c\ }
\DeclareInputText{"0FD}{\H{}}
\DeclareInputText{"0FE}{\k{}}
\DeclareInputText{"0FF}{\v{}}
\endinput
%% 
%% End of file `applemac.def'.
