%% 
%% This is file `pctexhp.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `pctexhp')

%% drivers.dtx Copyright (C) 1994--1996 David Carlisle Sebastian Rahtz
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%%
%% It should be distributed *unchanged* and together with all other
%% files in the graphics bundle. The file 00readme.txt contains a list
%% of all of these files.
%%
%% A modified version of this file may be distributed, but it should
%% be distributed with a *different* name. Changed files must be
%% distributed *together with a complete and unchanged* distribution
%% of these files.
%%
\ProvidesFile{pctexhp.def}
        [1996/05/29 v3.00 Driver-dependant file (DPC,SPQR)]
\def\Ginclude@pcl#1{%
\message{<#1>}%
   \ifGin@clip
     \typeout{no clipping support in pctexhp}%
   \fi
   \hbox{\kern-\Gin@llx bp\raise-\Gin@lly bp\hbox{\special{pcl:#1}}}%
   \typeout{WARNING: pctexhp does not permit graphics to be scaled}}
\@namedef{Gin@rule@.pcl}#1{{pcl}{}{#1}}
\def\Gin@extensions{.pcl}
\endinput
%% 
%% End of file `pctexhp.def'.
