%% 
%% This is file `pubps.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `pubps,psrules')

%% drivers.dtx Copyright (C) 1994--1996 David Carlisle Sebastian Rahtz
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%%
%% It should be distributed *unchanged* and together with all other
%% files in the graphics bundle. The file 00readme.txt contains a list
%% of all of these files.
%%
%% A modified version of this file may be distributed, but it should
%% be distributed with a *different* name. Changed files must be
%% distributed *together with a complete and unchanged* distribution
%% of these files.
%%
\ProvidesFile{pubps.def}
        [1996/05/29 v3.00 Driver-dependant file (DPC,SPQR)]
\def\Grot@start{\special{ps: gsave currentpoint
        currentpoint translate \Grot@angle\space
        rotate  neg exch neg exch translate}}
\def\Grot@end{\special{ps: currentpoint grestore moveto}}
\def\Gin@extensions{.eps,.ps}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\@namedef{Gin@rule@*}#1{{eps}{\Gin@ext}{#1}}
\endinput
%% 
%% End of file `pubps.def'.
