%% 
%% This is file `latin2.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% inputenc.dtx  (with options: `latin2')
%% 
%% 
%% This is a generated file. 
%% 
%% Copyright 1993 1994 1995 1996 
%% The LaTeX3 Project and any individual authors listed elsewhere 
%% in this file. 
%% 
%% For further copyright information, and conditions for modification 
%% and distribution, see the file legal.txt, and any other copyright 
%% notices in this file. 
%% 
%% This file is part of the LaTeX2e system. 
%% ---------------------------------------- 
%% This system is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
%% For error reports concerning UNCHANGED versions of this file no 
%% more than one year old, see bugs.txt. 
%% 
%% Please do not request updates from us directly. Primary 
%% distribution is through the CTAN archives. 
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE: 
%% 
%% You are NOT ALLOWED to distribute this file alone. 
%% 
%% You are allowed to distribute this file under the condition that it 
%% is distributed together with all the files listed in manifest.txt. 
%% 
%% If you receive only some of these files from someone, complain! 
%% 
%% 
%% Permission is granted to copy this file to another file with a 
%% clearly different name and to customize the declarations in that 
%% copy to serve the needs of your installation, provided that you 
%% comply with the conditions in the file legal.txt. 
%% 
%% However, NO PERMISSION is granted to generate or to distribute a 
%% modified version of this file under its original name. 
%% 
%% You are NOT ALLOWED to change this file. 
%% 
%% 
%% MODIFICATION ADVICE: 
%% 
%% If you want to customize this file, it is best to make a copy of 
%% the source file(s) from which it was produced. Use a different 
%% name for your copy(ies) and modify the copy(ies); this will ensure 
%% that your modifications do not get overwritten when you install a 
%% new release of the standard system. You should also ensure that 
%% your modified source file does not generate any modified file with 
%% the same name as a standard file. 
%% 
%% You can then easily distribute your modifications by distributing 
%% the modified and renamed copy of the source file, taking care to 
%% observe the conditions in legal.txt; this will ensure that other 
%% users can safely use your modifications. 
%% 
%% You will also need to produce your own, suitably named, .ins file to 
%% control the generation of files from your source file; this file 
%% should contain your own preambles for the files it generates, not 
%% those in the standard .ins files. 
%% 
%% The names of the source files used are shown above. 
%% 
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
 \ProvidesFile{latin2.def}
   [1996/05/10 v0.9r Input encoding file
                        (test version: liable to change)]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\DeclareInputText{"0A0}{\nobreakspace}
\DeclareInputText{"0B0}{\r{}}
\DeclareInputText{"0A1}{\k A}
\DeclareInputText{"0B1}{\k a}
\DeclareInputText{"0A2}{\u{}}
\DeclareInputText{"0B2}{\k\ }
\DeclareInputText{"0A3}{\L}
\DeclareInputText{"0B3}{\l}
\DeclareInputText{"0A4}{\textcurrency}
\DeclareInputText{"0B4}{\@tabacckludge'{}}
\DeclareInputText{"0A5}{\v L}
\DeclareInputText{"0B5}{\v l}
\DeclareInputText{"0A6}{\@tabacckludge'S}
\DeclareInputText{"0B6}{\@tabacckludge's}
\DeclareInputText{"0A7}{\S}
\DeclareInputText{"0B7}{\v{}}
\DeclareInputText{"0A8}{\"{}}
\DeclareInputText{"0B8}{\c\ }
\DeclareInputText{"0A9}{\v S}
\DeclareInputText{"0B9}{\v s}
\DeclareInputText{"0AA}{\c S}
\DeclareInputText{"0BA}{\c s}
\DeclareInputText{"0AB}{\v T}
\DeclareInputText{"0BB}{\v t}
\DeclareInputText{"0AC}{\@tabacckludge'Z}
\DeclareInputText{"0BC}{\@tabacckludge'z}
\DeclareInputText{"0AD}{\-}
\DeclareInputText{"0BD}{\H{}}
\DeclareInputText{"0AE}{\v Z}
\DeclareInputText{"0BE}{\v z}
\DeclareInputText{"0AF}{\.Z}
\DeclareInputText{"0BF}{\.z}
\DeclareInputText{"0C0}{\@tabacckludge'R}
\DeclareInputText{"0D0}{\DH}
\DeclareInputText{"0C1}{\@tabacckludge'A}
\DeclareInputText{"0D1}{\@tabacckludge'N}
\DeclareInputText{"0C2}{\^A}
\DeclareInputText{"0D2}{\v N}
\DeclareInputText{"0C3}{\u A}
\DeclareInputText{"0D3}{\@tabacckludge'O}
\DeclareInputText{"0C4}{\"A}
\DeclareInputText{"0D4}{\^O}
\DeclareInputText{"0C5}{\@tabacckludge'L}
\DeclareInputText{"0D5}{\H O}
\DeclareInputText{"0C6}{\@tabacckludge'C}
\DeclareInputText{"0D6}{\"O}
\DeclareInputText{"0C7}{\c C}
\DeclareInputMath{"0D7}{\times}
\DeclareInputText{"0C8}{\v C}
\DeclareInputText{"0D8}{\v R}
\DeclareInputText{"0C9}{\@tabacckludge'E}
\DeclareInputText{"0D9}{\r U}
\DeclareInputText{"0CA}{\k E}
\DeclareInputText{"0DA}{\@tabacckludge'U}
\DeclareInputText{"0CB}{\"E}
\DeclareInputText{"0DB}{\H U}
\DeclareInputText{"0CC}{\v E}
\DeclareInputText{"0DC}{\"U}
\DeclareInputText{"0CD}{\@tabacckludge'I}
\DeclareInputText{"0DD}{\@tabacckludge'Y}
\DeclareInputText{"0CE}{\^I}
\DeclareInputText{"0DE}{\c T}
\DeclareInputText{"0CF}{\v D}
\DeclareInputText{"0DF}{\ss}
\DeclareInputText{"0E0}{\@tabacckludge'r}
\DeclareInputText{"0F0}{\dh}
\DeclareInputText{"0E1}{\@tabacckludge'a}
\DeclareInputText{"0F1}{\@tabacckludge'n}
\DeclareInputText{"0E2}{\^a}
\DeclareInputText{"0F2}{\v n}
\DeclareInputText{"0E3}{\u a}
\DeclareInputText{"0F3}{\@tabacckludge'o}
\DeclareInputText{"0E4}{\"a}
\DeclareInputText{"0F4}{\^o}
\DeclareInputText{"0E5}{\@tabacckludge'l}
\DeclareInputText{"0F5}{\H o}
\DeclareInputText{"0E6}{\@tabacckludge'c}
\DeclareInputText{"0F6}{\"o}
\DeclareInputText{"0E7}{\c c}
\DeclareInputMath{"0F7}{\div}
\DeclareInputText{"0E8}{\v c}
\DeclareInputText{"0F8}{\v r}
\DeclareInputText{"0E9}{\@tabacckludge'e}
\DeclareInputText{"0F9}{\r u}
\DeclareInputText{"0EA}{\k e}
\DeclareInputText{"0FA}{\@tabacckludge'u}
\DeclareInputText{"0EB}{\"e}
\DeclareInputText{"0FB}{\H u}
\DeclareInputText{"0EC}{\v e}
\DeclareInputText{"0FC}{\"u}
\DeclareInputText{"0ED}{\@tabacckludge'\i}
\DeclareInputText{"0FD}{\@tabacckludge'y}
\DeclareInputText{"0EE}{\^\i}
\DeclareInputText{"0FE}{\c t}
\DeclareInputText{"0EF}{\v d}
\DeclareInputText{"0FF}{\.{}}
\endinput
%% 
%% End of file `latin2.def'.
