%% 
%% This is file `next.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% inputenc.dtx  (with options: `next')
%% 
%% 
%% This is a generated file. 
%% 
%% Copyright 1993 1994 1995 1996 
%% The LaTeX3 Project and any individual authors listed elsewhere 
%% in this file. 
%% 
%% For further copyright information, and conditions for modification 
%% and distribution, see the file legal.txt, and any other copyright 
%% notices in this file. 
%% 
%% This file is part of the LaTeX2e system. 
%% ---------------------------------------- 
%% This system is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
%% For error reports concerning UNCHANGED versions of this file no 
%% more than one year old, see bugs.txt. 
%% 
%% Please do not request updates from us directly. Primary 
%% distribution is through the CTAN archives. 
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE: 
%% 
%% You are NOT ALLOWED to distribute this file alone. 
%% 
%% You are allowed to distribute this file under the condition that it 
%% is distributed together with all the files listed in manifest.txt. 
%% 
%% If you receive only some of these files from someone, complain! 
%% 
%% 
%% Permission is granted to copy this file to another file with a 
%% clearly different name and to customize the declarations in that 
%% copy to serve the needs of your installation, provided that you 
%% comply with the conditions in the file legal.txt. 
%% 
%% However, NO PERMISSION is granted to generate or to distribute a 
%% modified version of this file under its original name. 
%% 
%% You are NOT ALLOWED to change this file. 
%% 
%% 
%% MODIFICATION ADVICE: 
%% 
%% If you want to customize this file, it is best to make a copy of 
%% the source file(s) from which it was produced. Use a different 
%% name for your copy(ies) and modify the copy(ies); this will ensure 
%% that your modifications do not get overwritten when you install a 
%% new release of the standard system. You should also ensure that 
%% your modified source file does not generate any modified file with 
%% the same name as a standard file. 
%% 
%% You can then easily distribute your modifications by distributing 
%% the modified and renamed copy of the source file, taking care to 
%% observe the conditions in legal.txt; this will ensure that other 
%% users can safely use your modifications. 
%% 
%% You will also need to produce your own, suitably named, .ins file to 
%% control the generation of files from your source file; this file 
%% should contain your own preambles for the files it generates, not 
%% those in the standard .ins files. 
%% 
%% The names of the source files used are shown above. 
%% 
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
  \ProvidesFile{next.def}
   [1996/05/10 v0.9r Input encoding file
                        (test version: liable to change)]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textquotesinglbase}{,}
\ProvideTextCommandDefault{\textquotedblbase}{,,}
\ProvideTextCommandDefault{\textquotesingle}
   {\TextSymbolUnavailable\textquotesingle}
\providecommand{\mathdegree}{{^\circ}}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathordmasculine}{{^o}}
\providecommand{\mathordfeminine}{{^a}}
\DeclareInputText{"080}{\nobreakspace}
\DeclareInputText{"081}{\@tabacckludge`A}
\DeclareInputText{"082}{\@tabacckludge'A}
\DeclareInputText{"083}{\^A}
\DeclareInputText{"084}{\~A}
\DeclareInputText{"085}{\"A}
\DeclareInputText{"086}{\AA}
\DeclareInputText{"087}{\c C}
\DeclareInputText{"088}{\@tabacckludge`E}
\DeclareInputText{"089}{\@tabacckludge'E}
\DeclareInputText{"08A}{\^E}
\DeclareInputText{"08B}{\"E}
\DeclareInputText{"08C}{\@tabacckludge`I}
\DeclareInputText{"08D}{\@tabacckludge'I}
\DeclareInputText{"08E}{\^I}
\DeclareInputText{"08F}{\"I}
\DeclareInputText{"091}{\~N}
\DeclareInputText{"092}{\@tabacckludge`O}
\DeclareInputText{"093}{\@tabacckludge'O}
\DeclareInputText{"094}{\^O}
\DeclareInputText{"095}{\~O}
\DeclareInputText{"096}{\"O}
\DeclareInputText{"097}{\@tabacckludge`U}
\DeclareInputText{"098}{\@tabacckludge'U}
\DeclareInputText{"099}{\^U}
\DeclareInputText{"09A}{\"U}
\DeclareInputText{"09B}{\@tabacckludge'Y}
\DeclareInputMath{"09D}{\mu}
\DeclareInputMath{"09E}{\times}
\DeclareInputMath{"09F}{\div}
\DeclareInputText{"0A0}{\copyright}
\DeclareInputText{"0A1}{\textexclamdown}
\DeclareInputText{"0A3}{\pounds}
\DeclareInputMath{"0A4}{/}
\DeclareInputText{"0A6}{\textflorin}
\DeclareInputText{"0A7}{\S}
\DeclareInputText{"0A9}{\textquotesingle}
\DeclareInputText{"0AA}{\textquotedblleft}
\DeclareInputText{"0AE}{fi}
\DeclareInputText{"0AF}{fl}
\DeclareInputText{"0B1}{\textendash}
\DeclareInputText{"0B2}{\dag}
\DeclareInputText{"0B3}{\ddag}
\DeclareInputText{"0B4}{\textperiodcentered}
\DeclareInputText{"0B5}{\textbar}
\DeclareInputText{"0B6}{\P}
\DeclareInputText{"0B7}{\textbullet}
\DeclareInputText{"0B8}{\textquotesinglbase}
\DeclareInputText{"0B9}{\textquotedblbase}
\DeclareInputText{"0BA}{\textquotedblright}
\DeclareInputText{"0BC}{\textellipsis}
\DeclareInputMath{"0BE}{\lnot}
\DeclareInputText{"0BF}{\textquestiondown}
\DeclareInputMath{"0C0}{\mathonesuperior}
\DeclareInputText{"0C1}{\@tabacckludge`{}}
\DeclareInputText{"0C2}{\@tabacckludge'{}}
\DeclareInputText{"0C3}{\^{}}
\DeclareInputText{"0C4}{\~{}}
\DeclareInputText{"0C5}{\@tabacckludge={}}
\DeclareInputText{"0C6}{\u{}}
\DeclareInputText{"0C7}{\.{}}
\DeclareInputText{"0C8}{\"{}}
\DeclareInputMath{"0C9}{\mathtwosuperior}
\DeclareInputMath{"0CA}{\mathdegree}
\DeclareInputText{"0CB}{\c\ }
\DeclareInputMath{"0CC}{\maththreesuperior}
\DeclareInputText{"0CD}{\H{}}
\DeclareInputText{"0CF}{\v{}}
\DeclareInputText{"0D0}{\textemdash}
\DeclareInputMath{"0D1}{\pm}
\DeclareInputText{"0D2}{\textonequarter}
\DeclareInputText{"0D3}{\textonehalf}
\DeclareInputText{"0D4}{\textthreequarters}
\DeclareInputText{"0D5}{\@tabacckludge`a}
\DeclareInputText{"0D6}{\@tabacckludge'a}
\DeclareInputText{"0D7}{\^a}
\DeclareInputText{"0D8}{\~a}
\DeclareInputText{"0D9}{\"a}
\DeclareInputText{"0DA}{\aa}
\DeclareInputText{"0DB}{\c c}
\DeclareInputText{"0DC}{\@tabacckludge`e}
\DeclareInputText{"0DD}{\@tabacckludge'e}
\DeclareInputText{"0DE}{\^e}
\DeclareInputText{"0DF}{\"e}
\DeclareInputText{"0E0}{\@tabacckludge`\i}
\DeclareInputText{"0E1}{\AE}
\DeclareInputText{"0E2}{\@tabacckludge'\i}
\DeclareInputMath{"0E3}{\mathordfeminine}
\DeclareInputText{"0E4}{\^\i}
\DeclareInputText{"0E5}{\"\i}
\DeclareInputText{"0E7}{\~n}
\DeclareInputText{"0E8}{\L}
\DeclareInputText{"0E9}{\O}
\DeclareInputText{"0EA}{\OE}
\DeclareInputMath{"0EB}{\mathordmasculine}
\DeclareInputText{"0EC}{\@tabacckludge`o}
\DeclareInputText{"0ED}{\@tabacckludge'o}
\DeclareInputText{"0EE}{\^o}
\DeclareInputText{"0EF}{\~o}
\DeclareInputText{"0F0}{\"o}
\DeclareInputText{"0F1}{\ae}
\DeclareInputText{"0F2}{\@tabacckludge`u}
\DeclareInputText{"0F3}{\@tabacckludge'u}
\DeclareInputText{"0F4}{\^u}
\DeclareInputText{"0F5}{\i}
\DeclareInputText{"0F6}{\"u}
\DeclareInputText{"0F7}{\@tabacckludge'y}
\DeclareInputText{"0F8}{\l}
\DeclareInputText{"0F9}{\o}
\DeclareInputText{"0FA}{\oe}
\DeclareInputText{"0FB}{\ss}
\DeclareInputText{"0FD}{\"y}
\endinput
%% 
%% End of file `next.def'.
