%% 
%% This is file `cp850.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% inputenc.dtx  (with options: `cp850')
%% 
%% 
%% This is a generated file. 
%% 
%% Copyright 1993 1994 1995 1996 
%% The LaTeX3 Project and any individual authors listed elsewhere 
%% in this file. 
%% 
%% For further copyright information, and conditions for modification 
%% and distribution, see the file legal.txt, and any other copyright 
%% notices in this file. 
%% 
%% This file is part of the LaTeX2e system. 
%% ---------------------------------------- 
%% This system is distributed in the hope that it will be useful, 
%% but WITHOUT ANY WARRANTY; without even the implied warranty of 
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
%% 
%% For error reports concerning UNCHANGED versions of this file no 
%% more than one year old, see bugs.txt. 
%% 
%% Please do not request updates from us directly. Primary 
%% distribution is through the CTAN archives. 
%% 
%% 
%% IMPORTANT COPYRIGHT NOTICE: 
%% 
%% You are NOT ALLOWED to distribute this file alone. 
%% 
%% You are allowed to distribute this file under the condition that it 
%% is distributed together with all the files listed in manifest.txt. 
%% 
%% If you receive only some of these files from someone, complain! 
%% 
%% 
%% Permission is granted to copy this file to another file with a 
%% clearly different name and to customize the declarations in that 
%% copy to serve the needs of your installation, provided that you 
%% comply with the conditions in the file legal.txt. 
%% 
%% However, NO PERMISSION is granted to generate or to distribute a 
%% modified version of this file under its original name. 
%% 
%% You are NOT ALLOWED to change this file. 
%% 
%% 
%% MODIFICATION ADVICE: 
%% 
%% If you want to customize this file, it is best to make a copy of 
%% the source file(s) from which it was produced. Use a different 
%% name for your copy(ies) and modify the copy(ies); this will ensure 
%% that your modifications do not get overwritten when you install a 
%% new release of the standard system. You should also ensure that 
%% your modified source file does not generate any modified file with 
%% the same name as a standard file. 
%% 
%% You can then easily distribute your modifications by distributing 
%% the modified and renamed copy of the source file, taking care to 
%% observe the conditions in legal.txt; this will ensure that other 
%% users can safely use your modifications. 
%% 
%% You will also need to produce your own, suitably named, .ins file to 
%% control the generation of files from your source file; this file 
%% should contain your own preambles for the files it generates, not 
%% those in the standard .ins files. 
%% 
%% The names of the source files used are shown above. 
%% 
%% 
%% 
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
  \ProvidesFile{cp850.def}
   [1996/05/10 v0.9r Input encoding file
                        (test version: liable to change)]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\providecommand{\mathdegree}{{^\circ}}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathordmasculine}{{^o}}
\providecommand{\mathordfeminine}{{^a}}
\DeclareInputText{"080}{\c C}
\DeclareInputText{"090}{\@tabacckludge'E}
\DeclareInputText{"081}{\"u}
\DeclareInputText{"091}{\ae}
\DeclareInputText{"082}{\@tabacckludge'e}
\DeclareInputText{"092}{\AE}
\DeclareInputText{"083}{\^a}
\DeclareInputText{"093}{\^o}
\DeclareInputText{"084}{\"a}
\DeclareInputText{"094}{\"o}
\DeclareInputText{"085}{\@tabacckludge`a}
\DeclareInputText{"095}{\@tabacckludge`o}
\DeclareInputText{"086}{\aa}
\DeclareInputText{"096}{\^u}
\DeclareInputText{"087}{\c c}
\DeclareInputText{"097}{\@tabacckludge`u}
\DeclareInputText{"088}{\^e}
\DeclareInputText{"098}{\"y}
\DeclareInputText{"089}{\"e}
\DeclareInputText{"099}{\"O}
\DeclareInputText{"08A}{\@tabacckludge`e}
\DeclareInputText{"09A}{\"U}
\DeclareInputText{"08B}{\"\i}
\DeclareInputText{"09B}{\o}
\DeclareInputText{"08C}{\^\i}
\DeclareInputText{"09C}{\pounds}
\DeclareInputText{"08D}{\@tabacckludge`\i}
\DeclareInputText{"09D}{\O}
\DeclareInputText{"08E}{\"A}
\DeclareInputMath{"09E}{\times}
\DeclareInputText{"08F}{\AA}
\DeclareInputText{"09F}{\textflorin}
\DeclareInputText{"0A0}{\@tabacckludge'a}
\DeclareInputText{"0A1}{\@tabacckludge'\i}
\DeclareInputText{"0A2}{\@tabacckludge'o}
\DeclareInputText{"0A3}{\@tabacckludge'u}
\DeclareInputText{"0A4}{\~n}               %% "B0-"B4: DG
\DeclareInputText{"0A5}{\~N}
\DeclareInputText{"0B5}{\@tabacckludge'A}
\DeclareInputMath{"0A6}{\mathordmasculine}
\DeclareInputText{"0B6}{\^A}
\DeclareInputMath{"0A7}{\mathordfeminine}
\DeclareInputText{"0B7}{\@tabacckludge`A}
\DeclareInputText{"0A8}{\textquestiondown}
\DeclareInputText{"0B8}{\copyright}
\DeclareInputText{"0A9}{\textregistered}
\DeclareInputMath{"0AA}{\lnot}
\DeclareInputText{"0AB}{\textonehalf}
\DeclareInputText{"0AC}{\textonequarter}   %% "B9-"BC: DG
\DeclareInputText{"0AD}{\textexclamdown}
\DeclareInputText{"0BD}{\textcent}
\DeclareInputText{"0AE}{\guillemotleft}
\DeclareInputText{"0BE}{\textyen}
\DeclareInputText{"0AF}{\guillemotright}
\DeclareInputText{"0D0}{\dh}
\DeclareInputText{"0D1}{\DH}
\DeclareInputText{"0D2}{\^E}
\DeclareInputText{"0D3}{\"E}
\DeclareInputText{"0D4}{\@tabacckludge`E}
\DeclareInputText{"0D5}{\i}
\DeclareInputText{"0C6}{\~a}
\DeclareInputText{"0D6}{\@tabacckludge'I}
\DeclareInputText{"0C7}{\~A}
\DeclareInputText{"0D7}{\^I}
\DeclareInputText{"0D8}{\"I}
\DeclareInputText{"0DD}{\textbrokenbar}
\DeclareInputText{"0DE}{\@tabacckludge`I}
\DeclareInputText{"0CF}{\textcurrency}  %% "DF: DG
\DeclareInputText{"0E0}{\@tabacckludge'O}
\DeclareInputText{"0F0}{\textendash}
\DeclareInputText{"0E1}{\ss}
\DeclareInputMath{"0F1}{\pm}
\DeclareInputText{"0E2}{\^O}   %% "F2: DG (double underline)
\DeclareInputText{"0E3}{\@tabacckludge`O}
\DeclareInputText{"0F3}{\textthreequarters}
\DeclareInputText{"0E4}{\~o}
\DeclareInputText{"0F4}{\P}
\DeclareInputText{"0E5}{\~O}
\DeclareInputText{"0F5}{\S}
\DeclareInputMath{"0E6}{\mu}
\DeclareInputMath{"0F6}{\div}
\DeclareInputText{"0E7}{\th}
\DeclareInputText{"0F7}{\c\ }
\DeclareInputText{"0E8}{\TH}
\DeclareInputMath{"0F8}{\mathdegree}
\DeclareInputText{"0E9}{\@tabacckludge'U}
\DeclareInputText{"0F9}{\"{}}
\DeclareInputText{"0EA}{\^U}
\DeclareInputText{"0FA}{\textperiodcentered}
\DeclareInputText{"0EB}{\@tabacckludge`U}
\DeclareInputMath{"0FB}{\mathonesuperior}
\DeclareInputText{"0EC}{\@tabacckludge'y}
\DeclareInputMath{"0FC}{\maththreesuperior}
\DeclareInputText{"0ED}{\@tabacckludge'Y}
\DeclareInputMath{"0FD}{\mathtwosuperior}
\DeclareInputText{"0EE}{\@tabacckludge={}}  %% "FE: DG (box)
\DeclareInputText{"0EF}{\@tabacckludge'{}}
\DeclareInputText{"0FF}{\nobreakspace}
\endinput
%% 
%% End of file `cp850.def'.
