%% 
%% This is file `psprint.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `psprint,psrules')

%% drivers.dtx Copyright (C) 1994--1996 David Carlisle Sebastian Rahtz
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%%
%% It should be distributed *unchanged* and together with all other
%% files in the graphics bundle. The file 00readme.txt contains a list
%% of all of these files.
%%
%% A modified version of this file may be distributed, but it should
%% be distributed with a *different* name. Changed files must be
%% distributed *together with a complete and unchanged* distribution
%% of these files.
%%
\ProvidesFile{psprint.def}
        [1996/05/29 v3.00 Driver-dependant file (DPC,SPQR)]
\def\Ginclude@eps#1{%
   \def\@tempa{!}%
   \ifx\Gin@scaley\@tempa
     \let\Gin@scaley\Gin@scalex
   \else
     \ifx\Gin@scalex\@tempa\let\Gin@scalex\Gin@scaley\fi
   \fi
   \ifGin@clip
     \typeout{no clipping support in psprint}%
   \fi
   \special{#1\space
       \Gin@scalex\space \Gin@scaley\space scale
       \Gin@llx\space neg
       \Gin@lly \space neg translate
}%
}
\def\Gin@extensions{.eps,.ps}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\@namedef{Gin@rule@*}#1{{eps}{\Gin@ext}{#1}}
\endinput
%% 
%% End of file `psprint.def'.
