%% 
%% This is file `dvitops.def',
%% generated with the docstrip utility.
%% 
%% The original source files were:
%% 
%% drivers.dtx  (with options: `dvitops,psrules')

%% drivers.dtx Copyright (C) 1994--1996 David Carlisle Sebastian Rahtz
%%
%% This file is part of the Standard LaTeX `Graphics Bundle'.
%%
%% It should be distributed *unchanged* and together with all other
%% files in the graphics bundle. The file 00readme.txt contains a list
%% of all of these files.
%%
%% A modified version of this file may be distributed, but it should
%% be distributed with a *different* name. Changed files must be
%% distributed *together with a complete and unchanged* distribution
%% of these files.
%%
\ProvidesFile{dvitops.def}
        [1996/05/29 v3.00 Driver-dependant file (DPC,SPQR)]
\newcount\Grot@count
\Grot@count=\@ne
\def\Grot@start{\special{dvitops: origin
    rot\the\@tempdima}%
\special{dvitops: begin rot\the\Grot@count}}%
\def\Grot@end{\special{dvitops: end}%
\special{dvitops: rotate rot\the\Grot@count \space
    \Grot@angle}%
\global\advance\Grot@count by\@ne}%
\def\Ginclude@eps#1{%
\ifGin@clip
  \typeout{no clipping support in dvitops}%
\fi
\special{import #1\space \the\Gin@req@width\space
                         \the\Gin@req@height\space fill}}
\def\Gin@extensions{.eps,.ps}
\@namedef{Gin@rule@.ps}#1{{eps}{.ps}{#1}}
\@namedef{Gin@rule@.eps}#1{{eps}{.eps}{#1}}
\@namedef{Gin@rule@*}#1{{eps}{\Gin@ext}{#1}}
\endinput
%% 
%% End of file `dvitops.def'.
